Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/mcp_atlassian/__init__.py | 46 | 26 | 0 | 43%
src/mcp_atlassian/config.py | 17 | 2 | 0 | 88%
src/mcp_atlassian/confluence.py | 77 | 0 | 0 | 100%
src/mcp_atlassian/document_types.py | 5 | 0 | 0 | 100%
src/mcp_atlassian/jira.py | 100 | 3 | 0 | 97%
src/mcp_atlassian/preprocessing.py | 83 | 11 | 0 | 87%
src/mcp_atlassian/server.py | 141 | 141 | 0 | 0%
Total | 469 | 183 | 0 | 61%

No items found using the specified filter.